@@ -1,6 +1,12 @@
+#!/usr/bin/python
+## -*- coding: utf-8 -*-
+
 import ast
 import os
 from os.path import expanduser
+import sys
+reload(sys)
+sys.setdefaultencoding( "utf-8" )
 try:
     import simplejson as json
 except (ImportError, SyntaxError):
