@@ -1,3 +1,6 @@
+#!/usr/bin/python
+## -*- coding: utf-8 -*-
+
 import os,sys
 import time
 from os.path import expanduser
@@ -14,11 +17,29 @@ from wcs.services.uploadprogressrecorder import UploadProgressRecorder
 
 config_file = os.path.join(expanduser("~"), ".wcscfg")
 
-
 lock = Lock()
 
 class MultipartUpload(object):
-    
+    """分片上传类
+    分片上传引入了块和片，一个文件由一到多个块组成，而每个块由一到多个片组成，块大小和片大小是可配的。块之间可以并发上传也可以顺序上传，块内的片之间只能顺序上传
+    分片上传通过导入UploadProgressRecorder实现断点续传
+    Attributes:
+        url: 上传域名
+        token: 鉴权token
+        path: 源文件路径
+        size: 源文件大小
+        key: 源文件名
+        blocknum: 源文件块数目
+        results: 读取上传进度到这个变量
+        uploadBatch: upload id
+        progress: 当前上传进度
+        recorder: UploadProgressRecorder的实例
+        cfg: Config的实例
+        concurrency: 块并发度
+        block_size: 块大小
+        bput_size: 片大小
+        
+    """   
     def __init__(self,url):
         self.url = url
         self.token = ''
@@ -212,6 +233,7 @@ class MultipartUpload(object):
 
     def _initial_records(self):
         self.uploadBatch = GetUuid()
+        debug('New upload id: %s' % self.uploadBatch)
         self.recorder = UploadProgressRecorder(self.uploadBatch)
 
     def upload(self,path,token,upload_id=None):
